Discover Packages
github.com/nagygr/saxparser
package
module
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Nov 21, 2021
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
README
¶
SaxParser
A SAX parser in Go.
It parses an XML without loading the entire contents into memory. Instead it
uses callback functions to notify the user of the different elements as it goes
along the file.
Expand ▾
Collapse ▴
Documentation
¶
type SaxHandler interface {
Characters(chars []byte )
Comment(chars []byte )
Directive(chars []byte )
EndElement(name string )
ProcessingInstruction(target string , instruction []byte )
StartElement(name string , attributes map[string ]string )
}
type SaxParser struct {
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.